#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chell-quickcheck
version:              0.2.5.4
visibility:           public
id:                   chell-quickcheck-0.2.5.4-6ZYdzqhHog6GqwfPr5CV7Y
key:                  chell-quickcheck-0.2.5.4-6ZYdzqhHog6GqwfPr5CV7Y
license:              MIT
maintainer:           Chris Martin, Julie Moronuki
author:               John Millikin <john@john-millikin.com>
homepage:             https://github.com/typeclasses/chell
synopsis:             QuickCheck support for Chell
description:          QuickCheck support for the Chell testing library.
category:             Testing
abi:                  47933b84bd7f14fbd31e2d97f262b18e
exposed:              True
exposed-modules:      Test.Chell.QuickCheck
import-dirs:          /usr/lib/ghc-9.6.6/site-local/chell-quickcheck-0.2.5.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/chell-quickcheck-0.2.5.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/chell-quickcheck-0.2.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chell-quickcheck
hs-libraries:         HSchell-quickcheck-0.2.5.4-6ZYdzqhHog6GqwfPr5CV7Y
depends:
    QuickCheck-2.15.0.1-JreQmzbtNzG6Tfv3OFDtCd base-4.18.2.1
    chell-0.5.0.2-B4A9xXD8hVuDY72mP3ZvNk
    random-1.2.1.3-EfuxxTSFZVsDtv0C5Jgv69

haddock-interfaces:
    /usr/share/doc/haskell-chell-quickcheck/html/chell-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-chell-quickcheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

